'use strict'
/* istanbul ignore file */

require('@metcoder95/https-pem/install')
